@@ -69,9 +69,6 @@ static gchar 	*get_dirname_from_uri 		(const char          *uri);
 static gboolean  gedit_file_save_as_real 	(const gchar         *file_name, 
 						 const GeditEncoding *encoding,
 						 GeditMDIChild       *child);
-static gboolean	 gedit_file_open_uri_list_real 	(GSList              *uri_list, 
-						 const GeditEncoding *encoding, 
-						 gboolean             create);
 static void	 open_files 			(void);
 static void	 show_progress_bar 		(gchar               *uri, 
 						 gboolean             show, 
@@ -147,7 +144,6 @@ gedit_file_new (void)
 void 
 gedit_file_close (GtkWidget *view)
 {
-	gint ret;
 	BonoboMDIChild* child;
 
 	gedit_debug (DEBUG_FILE, "");
@@ -159,18 +155,19 @@ gedit_file_close (GtkWidget *view)
 
 	if (g_list_length (bonobo_mdi_child_get_views (child)) > 1)
 	{		
-		ret = bonobo_mdi_remove_view (BONOBO_MDI (gedit_mdi), view, FALSE);
+		bonobo_mdi_remove_view (BONOBO_MDI (gedit_mdi), view, FALSE);
 		gedit_debug (DEBUG_COMMANDS, "View removed.");
 	}
 	else
 	{
-		ret = bonobo_mdi_remove_child (BONOBO_MDI (gedit_mdi), child, FALSE);
+		bonobo_mdi_remove_child (BONOBO_MDI (gedit_mdi), child, FALSE);
 		gedit_debug (DEBUG_COMMANDS, "Child removed.");
 	}
 
+	gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
+
 	if (bonobo_mdi_get_active_child (BONOBO_MDI (gedit_mdi)) == NULL)
 	{
-		gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
 		gedit_mdi_clear_active_window_statusbar (gedit_mdi);
 	}
 
@@ -217,7 +214,7 @@ gedit_file_open (GeditMDIChild *active_child)
 			default_path,
 			&encoding);
 
-	gedit_file_open_uri_list_real (files, encoding, TRUE);
+	gedit_file_open_uri_list (files, encoding, 0, TRUE);
 
 	g_slist_free (files);
 	g_free (default_path);
@@ -461,7 +458,9 @@ gedit_file_save_as (GeditMDIChild *child)
 }
 
 static gboolean
-gedit_file_save_as_real (const gchar* file_name, const GeditEncoding *encoding, GeditMDIChild *child)
+gedit_file_save_as_real (const gchar *file_name,
+			 const GeditEncoding *encoding,
+			 GeditMDIChild *child)
 {
 	gchar *uri;
 	gboolean ret;
@@ -475,7 +474,7 @@ gedit_file_save_as_real (const gchar* file_name, const GeditEncoding *encoding,
 	doc = child->document;
 	g_return_val_if_fail (doc != NULL, FALSE);
 
-	uri = eel_make_uri_canonical (file_name);
+	uri = gnome_vfs_make_uri_canonical (file_name);
 	g_return_val_if_fail (uri != NULL, FALSE);
 	
 	ret = gedit_document_save_as (doc, uri, encoding, &error);
@@ -488,11 +487,9 @@ gedit_file_save_as_real (const gchar* file_name, const GeditEncoding *encoding,
 					GTK_WINDOW (gedit_get_active_window ()));
 
 		g_error_free (error);
-		
 		g_free (uri);
 
 		return FALSE;
-		
 	}	
 	else
 	{
@@ -519,9 +516,10 @@ gedit_file_close_all (void)
 
 	ret = gedit_mdi_remove_all (gedit_mdi);
 
+	gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
+
 	if (bonobo_mdi_get_active_child (BONOBO_MDI (gedit_mdi)) == NULL)
 	{
-		gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
 		gedit_mdi_clear_active_window_statusbar (gedit_mdi); 
 	}
 
@@ -773,37 +771,29 @@ gedit_file_revert (GeditMDIChild *child)
 	gedit_debug (DEBUG_FILE, "");
 
 	g_return_if_fail (child != NULL);
-	
+
 	doc = child->document;
 	g_return_if_fail (doc != NULL);
-	
+
 	if (!gedit_file_revert_dialog (doc))
 		return;
-	
+
 	uri = gedit_document_get_uri (doc);
 	g_return_if_fail (uri != NULL);
-	
+
 	gedit_utils_flash_va (_("Reverting the document \"%s\"..."), uri);	
-	
+	g_free (uri);
+
 	g_signal_connect (G_OBJECT (doc),
 			  "loading",
 			  G_CALLBACK (document_loading_cb),
 			  (gpointer)TRUE);
-				  
 	g_signal_connect (G_OBJECT (doc),
 			  "loaded",
 			  G_CALLBACK (document_reverted_cb),
 			  NULL);
-	
-	gedit_document_revert (doc);
-}
 
-gboolean 
-gedit_file_open_uri_list (GSList* uri_list, gint l, gboolean create)
-{
-	line = l;
-	
-	return gedit_file_open_uri_list_real (uri_list, NULL, create);
+	gedit_document_revert (doc);
 }
 
 gboolean 
@@ -862,12 +852,12 @@ gedit_file_open_single_uri (const gchar* uri, const GeditEncoding *encoding)
 	
 	if (uri == NULL) 
 		return FALSE;
-	
+
 	full_path = eel_make_uri_from_input (uri);
 
 	uri_list = g_slist_prepend (NULL, full_path);
 	
-	gedit_file_open_uri_list_real (uri_list, encoding, FALSE);
+	gedit_file_open_uri_list (uri_list, encoding, 0, FALSE);
 
 	return TRUE;
 }
@@ -951,47 +941,22 @@ gedit_file_open_from_stdin (GeditMDIChild *active_child)
 }
 
 
-static gboolean
+static void 
 create_new_file (const gchar *uri)
 {
-	GtkWidget *dialog;
-	gboolean   created;
-	gchar     *formatted_uri;
+	gint ret;
+	GeditMDIChild *new_child;
 
-	formatted_uri = gnome_vfs_format_uri_for_display (uri);
-	g_return_val_if_fail (formatted_uri != NULL, FALSE);
-			
-	created = FALSE;
+	new_child = gedit_mdi_child_new_with_uri (uri, NULL);
+	ret = bonobo_mdi_add_child (BONOBO_MDI (gedit_mdi), BONOBO_MDI_CHILD (new_child));
+	g_return_if_fail (ret != FALSE);
+	gedit_debug (DEBUG_COMMANDS, "Child added.");
 
-	/* FIXME: Is it conforming to GNOME HIG ? - Paolo (Jan 02, 2004) */	
-	dialog = gtk_message_dialog_new (GTK_WINDOW (gedit_get_active_window ()),
-					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_QUESTION,
-					 GTK_BUTTONS_YES_NO,
-					 _("The file \"%s\" does not exist. Would you like to create it?"),
-					 formatted_uri);
+	ret = bonobo_mdi_add_view (BONOBO_MDI (gedit_mdi), BONOBO_MDI_CHILD (new_child));
+	g_return_if_fail (ret != FALSE);
+	gedit_debug (DEBUG_COMMANDS, "View added.");
 
-	g_free (formatted_uri);
-
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
-
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
-	{
-		created = gedit_utils_create_empty_file (uri);
-
-		if (!created)
-		{
-			gedit_utils_error_reporting_creating_file (uri, 
-								   errno, 
-								   GTK_WINDOW (dialog));
-		}
-	}
-									
-	gtk_widget_destroy (dialog);
-
-	return created;
+	gtk_widget_grab_focus (GTK_WIDGET (gedit_get_active_view ()));
 }
 
 static gboolean
@@ -1169,7 +1134,6 @@ set_progress_bar (gulong size, gulong total_size)
 	}
 }
 
-
 static void 
 document_loading_cb (GeditDocument *document,
 		     gulong         size,
@@ -1475,8 +1439,11 @@ open_files ()
 }
 
 /* Note that all the uris will be opened with the same encoding */
-static gboolean
-gedit_file_open_uri_list_real (GSList *uri_list, const GeditEncoding *encoding, gboolean create)
+gboolean
+gedit_file_open_uri_list (GSList *uri_list,
+			  const GeditEncoding *encoding,
+			  gint line_pos,
+			  gboolean create)
 {
 	gedit_debug (DEBUG_FILE, "");
 	
@@ -1520,10 +1487,7 @@ gedit_file_open_uri_list_real (GSList *uri_list, const GeditEncoding *encoding,
 			{
 				if (create)
 				{
-					if (create_new_file (uri))
-					{
-						uris_to_open = g_slist_prepend (uris_to_open, uri);
-					}
+					create_new_file (uri);
 				}
 				else
 				{
@@ -1550,7 +1514,8 @@ gedit_file_open_uri_list_real (GSList *uri_list, const GeditEncoding *encoding,
 		}
 
 		encoding_to_use = encoding;
-		
+		line = line_pos > 0 ? line_pos : 0;
+
 		gedit_mdi_set_state (gedit_mdi, GEDIT_STATE_LOADING);
 		
 		open_files ();
