@@ -240,18 +240,17 @@ gedit_utils_set_status_va (gchar *format, ...)
 	g_free (msg);
 }
 
-
 gboolean
 gedit_utils_uri_has_file_scheme (const gchar *uri)
 {
-	gchar* canonical_uri = NULL;
+	gchar *canonical_uri = NULL;
 	gboolean res;
-	
-	canonical_uri = eel_make_uri_canonical (uri);
+
+	canonical_uri = gnome_vfs_make_uri_canonical (uri);
 	g_return_val_if_fail (canonical_uri != NULL, FALSE);
 
 	res = eel_istr_has_prefix (canonical_uri, "file:");
-	
+
 	g_free (canonical_uri);
 
 	return res;
@@ -272,10 +271,10 @@ gedit_utils_is_uri_read_only (const gchar* uri)
 	/* FIXME: all remote files are marked as readonly */
 	if (!gedit_utils_uri_has_file_scheme (uri))
 		return TRUE;
-			
-	canonical_uri = eel_make_uri_canonical (uri);
+		
+	canonical_uri = gnome_vfs_make_uri_canonical (uri);
 	g_return_val_if_fail (canonical_uri != NULL, TRUE);
-	
+
 	gedit_debug (DEBUG_FILE, "CANONICAL URI: %s", canonical_uri);
 
 	file_uri = gnome_vfs_get_local_path_from_uri (canonical_uri);
@@ -294,17 +293,39 @@ gedit_utils_is_uri_read_only (const gchar* uri)
 	return res;	
 }
 
+/* lifted from eel */
+static GtkWidget *
+gedit_gtk_button_new_with_stock_icon (const gchar *label, const gchar *stock_id)
+{
+	GtkWidget *button, *l, *image, *hbox, *align;
+
+	/* This is mainly copied from gtk_button_construct_child(). */
+	button = gtk_button_new ();
+	l = gtk_label_new_with_mnemonic (label);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (l), GTK_WIDGET (button));
+	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+	hbox = gtk_hbox_new (FALSE, 2);
+	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox), l, FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (button), align);
+	gtk_container_add (GTK_CONTAINER (align), hbox);
+	gtk_widget_show_all (align);
+
+	return button;
+}
+
 GtkWidget*
 gedit_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stock_id,
 			 gint response_id)
 {
 	GtkWidget *button;
-	
+
 	g_return_val_if_fail (GTK_IS_DIALOG (dialog), NULL);
 	g_return_val_if_fail (text != NULL, NULL);
 	g_return_val_if_fail (stock_id != NULL, NULL);
 
-	button = eel_gtk_button_new_with_stock_icon (text, stock_id);
+	button = gedit_gtk_button_new_with_stock_icon (text, stock_id);
 	g_return_val_if_fail (button != NULL, NULL);
 
 	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
@@ -1208,47 +1229,6 @@ gedit_utils_convert_search_text (const gchar *text)
 	return g_string_free (str, FALSE);
 }
 
-gboolean
-gedit_utils_create_empty_file (const gchar *uri)
-{
-	gchar *canonical_uri;
-	gchar *filename;
-	int fd;
-	
-	g_return_val_if_fail (uri != NULL, FALSE);
-	
-	/* Get filename from uri */
-	if (!gedit_utils_uri_has_file_scheme (uri))
-		return FALSE;
-			
-	canonical_uri = eel_make_uri_canonical (uri);
-	g_return_val_if_fail (canonical_uri != NULL, FALSE);
-	
-	gedit_debug (DEBUG_FILE, "CANONICAL URI: %s", canonical_uri);
-
-	filename = gnome_vfs_get_local_path_from_uri (canonical_uri);
-	g_free (canonical_uri);
-	
-	if (filename == NULL)
-	{
-		gedit_debug (DEBUG_FILE, "FILENAME: NULL");
-
-		return FALSE;
-	}
-	
-	fd = open (filename, O_CREAT | O_EXCL | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
-
-	g_free (filename);
-	
-	if (fd == -1)
-		return FALSE;
-	
-	return (close (fd) == 0);
-}
-
-
-
-
 #define GEDIT_STDIN_BUFSIZE 1024
 
 gchar *
