@@ -44,6 +44,7 @@
 #include "gedit-mdi.h"
 #include "gedit-prefs-manager-app.h"
 #include "gedit-debug.h"
+#include "gedit-encodings.h"
 #include "gedit-file.h"
 #include "gedit-utils.h"
 #include "gedit-session.h"
@@ -57,10 +58,9 @@
 #endif
 
 GeditMDI *gedit_mdi = NULL;
-gboolean gedit_close_x_button_pressed = FALSE;
-gboolean gedit_exit_button_pressed = FALSE; 
 BonoboObject *gedit_app_server = NULL;
 
+static gchar *encoding_charset = NULL;
 static gboolean quit_option = FALSE;
 static gboolean new_window_option = FALSE;
 static gboolean new_document_option = FALSE;
@@ -70,6 +70,10 @@ typedef struct _CommandLineData CommandLineData;
 struct _CommandLineData
 {
 	GSList* file_list;
+
+	/* note that encoding is const and should not be freed */
+	const GeditEncoding *encoding;
+
 	gint line_pos;
 };
 
@@ -78,50 +82,8 @@ static void gedit_load_file_list (CommandLineData *data);
 
 static const struct poptOption options [] =
 {
-	{ "debug-utils", '\0', POPT_ARG_NONE, &debug_utils, 0,
-	  N_("Show utility debugging messages."), NULL },
-
-	{ "debug-metadata", '\0', POPT_ARG_NONE, &debug_utils, 0,
-	  N_("Show metadata debugging messages."), NULL },
-
-	{ "debug-mdi", '\0', POPT_ARG_NONE, &debug_mdi, 0,
-	  N_("Show mdi debugging messages."), NULL },
-
-	{ "debug-commands", '\0', POPT_ARG_NONE, &debug_commands, 0,
-	  N_("Show commands debugging messages."), NULL },
-
-	{ "debug-document", '\0', POPT_ARG_NONE, &debug_document, 0,
-	  N_("Show document debugging messages."), NULL },
-
-	{ "debug-file", '\0', POPT_ARG_NONE, &debug_file, 0,
-	  N_("Show file debugging messages."), NULL },
-
-	{ "debug-plugins", '\0', POPT_ARG_NONE, &debug_plugins, 0,
-	  N_("Show plugin debugging messages."), NULL },
-
-	{ "debug-prefs", '\0', POPT_ARG_NONE, &debug_prefs, 0,
-	  N_("Show prefs debugging messages."), NULL },
-
-	{ "debug-print", '\0', POPT_ARG_NONE, &debug_print, 0,
-	  N_("Show printing debugging messages."), NULL },
-
-	{ "debug-search", '\0', POPT_ARG_NONE, &debug_search, 0,
-	  N_("Show search debugging messages."), NULL },
-
-	{ "debug-undo", '\0', POPT_ARG_NONE, &debug_undo, 0,
-	  N_("Show undo debugging messages."), NULL },
-
-	{ "debug-view", '\0', POPT_ARG_NONE, &debug_view, 0,
-	  N_("Show view debugging messages."), NULL },
-
-	{ "debug-recent", '\0', POPT_ARG_NONE, &debug_recent, 0,
-	  N_("Show recent debugging messages."), NULL },
-
-	 { "debug-session", '\0', POPT_ARG_NONE, &debug_session, 0,
-	  N_("Show session management debugging messages."), NULL },
-
-	{ "debug", '\0', POPT_ARG_NONE, &debug, 0,
-	  N_("Turn on all debugging messages."), NULL },
+	{ "encoding", '\0', POPT_ARG_STRING, &encoding_charset,	0,
+	  N_("Set the character encoding to be used to open the files listed on the command line"), NULL },
 
 	{ "quit", '\0', POPT_ARG_NONE, &quit_option, 0,
 	  N_("Quit an existing instance of gedit"), NULL },
@@ -160,17 +122,16 @@ gedit_load_file_list (CommandLineData *data)
 	while (gtk_events_pending ())
 		gtk_main_iteration ();
 
-	gedit_file_new ();
-
 	res = gedit_file_open_from_stdin (NULL);
 
 	if (data == NULL) 
 	{
+		gedit_file_new ();
 		return;
 	}
-	
+
 	/* Load files */
-	gedit_file_open_uri_list (data->file_list, data->line_pos, TRUE);
+	gedit_file_open_uri_list (data->file_list, data->encoding, data->line_pos, TRUE);
 	
 	g_slist_foreach (data->file_list, (GFunc)g_free, NULL);
 	g_slist_free (data->file_list);
@@ -178,7 +139,6 @@ gedit_load_file_list (CommandLineData *data)
 	g_free (data);
 }
 
-
 static CommandLineData *
 gedit_get_command_line_data (GnomeProgram *program)
 {
@@ -214,13 +174,18 @@ gedit_get_command_line_data (GnomeProgram *program)
 		}
 
 		data->file_list = g_slist_reverse (data->file_list);
+
+		if (encoding_charset)
+		{
+			data->encoding = gedit_encoding_get_from_charset (encoding_charset);
+			if (data->encoding == NULL)
+				g_print (_("The specified encoding \"%s\" is not valid\n"), encoding_charset);
+		}
 	}
-		
+
 	return data;
 }
 
-
-
 static void
 gedit_handle_automation_cmdline (GnomeProgram *program)
 {
@@ -288,7 +253,6 @@ gedit_handle_automation_cmdline (GnomeProgram *program)
 		g_free (data);
 	}
 
-
 	stdin_data = gedit_utils_get_stdin ();
 
 	if (stdin_data != NULL && strlen (stdin_data) > 0)
@@ -392,6 +356,9 @@ main (int argc, char **argv)
                 exit (0);
         }
 
+	/* Setup debugging */
+	gedit_debug_init ();
+
 	/* Set default icon */
 	gedit_set_default_icon ();
 	
@@ -433,8 +400,7 @@ main (int argc, char **argv)
 	return 0;
 }
 
-
-BonoboWindow*
+BonoboWindow *
 gedit_get_active_window (void)
 {
 	g_return_val_if_fail (gedit_mdi != NULL, NULL);
@@ -442,7 +408,7 @@ gedit_get_active_window (void)
 	return	bonobo_mdi_get_active_window (BONOBO_MDI (gedit_mdi));
 }
 
-GeditDocument*
+GeditDocument *
 gedit_get_active_document (void)
 {
 	BonoboMDIChild *active_child;
@@ -457,7 +423,7 @@ gedit_get_active_document (void)
 	return GEDIT_MDI_CHILD (active_child)->document;
 }
 
-GeditView*
+GeditView *
 gedit_get_active_view (void)
 {
 	GtkWidget *active_view;
@@ -472,7 +438,7 @@ gedit_get_active_view (void)
 	return GEDIT_VIEW (active_view);
 }
 
-GList* 
+GList * 
 gedit_get_top_windows (void)
 {
 	g_return_val_if_fail (gedit_mdi != NULL, NULL);
@@ -480,7 +446,7 @@ gedit_get_top_windows (void)
 	return	bonobo_mdi_get_windows (BONOBO_MDI (gedit_mdi));
 }
 
-BonoboUIComponent*
+BonoboUIComponent *
 gedit_get_ui_component_from_window (BonoboWindow* win)
 {
 	g_return_val_if_fail (win != NULL, NULL);
@@ -489,7 +455,7 @@ gedit_get_ui_component_from_window (BonoboWindow* win)
 }
 
 /* Return a newly allocated list */
-GList*
+GList *
 gedit_get_open_documents (void)
 {
 	GList* children;
@@ -510,3 +476,11 @@ gedit_get_open_documents (void)
 	
 	return docs;
 }
+
+GeditMDI *
+gedit_get_mdi (void)
+{
+	g_return_val_if_fail (GEDIT_IS_MDI (gedit_mdi), NULL);
+
+	return gedit_mdi;
+}
